pub enum AttributeType {
Normal,
Whitelisted,
Gated(&'static str, &'static str),
CrateLevel,
}Variants
Normal | Normal, builtin attribute that is consumed
by the compiler before the unused_attribute check
|
Whitelisted | Builtin attribute that may not be consumed by the compiler
before the unused_attribute check. These attributes
will be ignored by the unused_attribute lint
|
Gated | Is gated by a given feature gate and reason
These get whitelisted too
|
CrateLevel | Builtin attribute that is only allowed at the crate level
|